@@ -1,4 +1,4 @@
-// $Id: syscall_getvxinfo.c,v 1.1 2004/01/21 18:47:18 ensc Exp $    --*- c -*--
+// $Id: syscall_getvxinfo.c,v 1.3 2005/10/29 10:31:42 ensc Exp $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -21,7 +21,7 @@
 #endif
 
 #include "vserver.h"
-#include "linuxvirtual.h"
+#include "virtual.h"
 
 #if defined(VC_ENABLE_API_OLDPROC) && defined(VC_ENABLE_API_V13)
 #  define VC_MULTIVERSION_SYSCALL	1
@@ -40,7 +40,7 @@ int
 vc_get_vx_info(xid_t xid, struct vc_vx_info *info)
 {
   if (info==0) {
-    errno = EINVAL;
+    errno = EFAULT;
     return -1;
   }
   CALL_VC(CALL_VC_V13    (vc_get_vx_info, xid, info),
