@@ -1,4 +1,4 @@
-// $Id: fstool.c,v 1.7 2004/03/05 03:26:18 ensc Exp $    --*- c -*--
+// $Id: fstool.c,v 1.9 2005/10/29 08:46:59 ensc Exp $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -42,29 +42,6 @@ struct Arguments const *		global_args = 0;
 
 int wrapper_exit_code = 1;
 
-bool
-checkForRace(int fd, char const * name, struct stat const *exp_st)
-{
-  struct stat		st;
-  
-  if (fstat(fd, &st)==-1) {
-    perror("fstat()");
-    return false;
- }
-
-  if (st.st_dev  != exp_st->st_dev ||
-      st.st_ino  != exp_st->st_ino ||
-      st.st_mode != exp_st->st_mode) {
-    close(fd);
-    WRITE_MSG(2, "race while visiting '");
-    WRITE_STR(2, name);
-    WRITE_MSG(2, "'\n");
-    exit(2);
-  }
-
-  return true;
-}
-
 inline static bool
 isSpecialDir(char const *d)
 {
@@ -179,8 +156,13 @@ processFile(char const *path)
   }
 
   if (S_ISDIR(st.st_mode) && !global_args->do_display_dir) {
+    int		cur_dir = Eopen(".", O_RDONLY, 0);
+    uint64_t	ret;
     Echdir(path);
-    return iterateFilesystem(path);
+    ret = iterateFilesystem(path);
+    Efchdir(cur_dir);
+    Eclose(cur_dir);
+    return ret;
   }
   else
     return handleFile(path, path) ? 0 : 1;
